@@ -22,7 +22,8 @@ import math
 import os
 import re
 from collections import UserDict, defaultdict
-from dataclasses import dataclass
+from dataclasses import dataclass, field
+from typing import Optional
 
 from scipy.interpolate import interp1d
 
@@ -83,14 +84,14 @@ class CalData:
     thrurefl: complex = complex(0.0, 0.0)
     isolation: complex = complex(0.0, 0.0)
     freq: int = 0
-    e00: float = 0.0  # Directivity
-    e11: float = 0.0  # Port1 match
-    delta_e: float = 0.0  # Tracking
-    e10e01: float = 0.0  # Forward Reflection Tracking
+    e00: complex = complex(0.0)  # Directivity
+    e11: complex = complex(0.0)  # Port1 match
+    delta_e:complex = complex(0.0)  # Tracking
+    e10e01: complex = complex(0.0)  # Forward Reflection Tracking
     # 2 port
-    e30: float = 0.0  # Forward isolation
-    e22: float = 0.0  # Port2 match
-    e10e32: float = 0.0  # Forward transmission
+    e30: complex = complex(0.0)  # Forward isolation
+    e22: complex = complex(0.0)  # Port2 match
+    e10e32: complex = complex(0.0)  # Forward transmission
 
     def __str__(self):
         return (
@@ -112,7 +113,7 @@ class CalData:
 class CalElement:
     # pylint: disable=too-many-instance-attributes
     short_state: str = ""
-    short_touchstone: Touchstone = None
+    short_touchstone: Touchstone = field(default_factory=Touchstone)
     short_is_ideal: bool = True
     short_l0: float = 5.7e-12
     short_l1: float = -8.96e-20
@@ -121,7 +122,7 @@ class CalElement:
     short_length: float = -34.2  # ps
 
     open_state: str = ""
-    open_touchstone: Touchstone = None
+    open_touchstone: Touchstone = field(default_factory=Touchstone)
     open_is_ideal: bool = True
     open_c0: float = 2.1e-14
     open_c1: float = 5.67e-23
@@ -130,7 +131,7 @@ class CalElement:
     open_length: float = 0.0
 
     load_state: str = ""
-    load_touchstone: Touchstone = None
+    load_touchstone: Touchstone = field(default_factory=Touchstone)
     load_is_ideal: bool = True
     load_r: float = 50.0
     load_l: float = 0.0
@@ -223,7 +224,7 @@ class CalDataSet(UserDict):
                 logger.warning(
                     "Caldata without having read header: %i: %s", i, line
                 )
-            self._append_match(m, header, line, i)
+            self._append_match(m, header, i, line)
         return self
 
     def insert(self, name: str, dp: Datapoint):
@@ -249,8 +250,10 @@ class CalDataSet(UserDict):
     def freq_max(self) -> int:
         return self.frequencies()[-1] if self.frequencies() else 0
 
-    def get(self, key: int, default: CalData = None) -> CalData:
-        return self.data.get(key, default)
+    def get(self, key: int, default: Optional[CalData] = None) -> CalData: # type: ignore[override]
+        if default:
+            return self.data.get(key, default)
+        return self.data[key]
 
     def items(self):
         yield from self.data.items()
